AquaticMapper extension

on

Properties

creatureType CreatureType?

Available on Aquatic, provided by the AquaticMapper extension

Maps the unified species type to its internal CreatureType model.
no setter
fishSpecies FishSpecies?

Available on Aquatic, provided by the AquaticMapper extension

Maps the unified species type to its internal FishSpecies model.
no setter
isFish bool

Available on Aquatic, provided by the AquaticMapper extension

Whether this species is a fish.
no setter