CreatureConfig class

Constructors

CreatureConfig({required String name, required Color primaryColor, required Color secondaryColor, required Color accentColor, required double size, required double maxSpeed, bool isSeabedDweller = false})
const

Properties

accentColor Color
final
hashCode int
The hash code for this object.
no setterinherited
isSeabedDweller bool
final
maxSpeed double
final
name String
final
primaryColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryColor Color
final
size double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getConfig(CreatureType type) CreatureConfig