Bubble class

Represents an animated water bubble rising upwards in the aquarium.

Constructors

Bubble({required Offset position, required double speed, required double radius, required double driftFrequency, required double driftAmplitude, double wobbleTime = 0.0})

Properties

driftAmplitude double
final
driftFrequency double
final
hashCode int
The hash code for this object.
no setterinherited
isExpired bool
Marks when the bubble rises past the top boundary of the screen.
no setter
position Offset
getter/setter pair
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double
final
wobbleTime double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(double dt) → void
Updates position of the bubble rising upwards with subtle sine wave horizontal wobble.

Operators

operator ==(Object other) bool
The equality operator.
inherited