Fish class
Constructors
Properties
- angle ↔ double
-
getter/setter pair
- angularVelocity ↔ double
-
getter/setter pair
- config → FishSpeciesConfig
-
final
- currentSpeed → double
-
no setter
- depth → double
-
final
- gillPhase ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
-
jointAngles
↔ List<
double> -
getter/setter pair
- loadingPhase ↔ FishLoadingPhase
-
getter/setter pair
- position ↔ Offset
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
final
- species → FishSpecies
-
final
-
spineJoints
↔ List<
Offset> -
getter/setter pair
- state ↔ FishState
-
getter/setter pair
- stateTimer ↔ double
-
getter/setter pair
- targetAngle ↔ double
-
getter/setter pair
- velocity ↔ Offset
-
getter/setter pair
- wigglePhase ↔ double
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited