FishSpeciesConfig class

Constructors

FishSpeciesConfig({required String name, required Color primaryColor, required Color secondaryColor, required Color accentColor, required Color finColor, required Color eyeColor, required double bodyLength, required double bodyWidth, required double maxSpeed, required double tailWiggleMultiplier})
const

Properties

accentColor Color
final
bodyLength double
final
bodyWidth double
final
eyeColor Color
final
finColor Color
final
hashCode int
The hash code for this object.
no setterinherited
maxSpeed double
final
name String
final
primaryColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryColor Color
final
tailWiggleMultiplier double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getConfig(FishSpecies species) FishSpeciesConfig