Ripple class

Constructors

Ripple({required Offset position, double radius = 2.0, double maxRadius = 180.0, double amplitude = 1.0, double speed = 150.0, double age = 0.0, double maxAge = 2.4})

Properties

age double
getter/setter pair
amplitude double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isExpired bool
no setter
maxAge double
final
maxRadius double
final
particles List<SplashParticle>
final
position Offset
final
radius double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double
final

Methods

getElevationAt(double d) double
Calculates wave displacement & optical refraction offset at distance d
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(double dt) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited