AquariumThemeData class

Constructors

AquariumThemeData({required String name, required Color deepWaterColor, required Color shallowWaterColor, required Color sandColor, required Color causticsColor, required List<Color> seaweedColors, required Color lightBeamColor, required Color rippleHighlight})
const

Properties

causticsColor Color
final
deepWaterColor Color
final
hashCode int
The hash code for this object.
no setterinherited
lightBeamColor Color
final
name String
final
rippleHighlight Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sandColor Color
final
seaweedColors List<Color>
final
shallowWaterColor Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getPreset(AquariumThemePreset preset) AquariumThemeData