startLoading method
void
startLoading()
Puts the aquarium into loading mode, attracting all fish to circle around the center.
Implementation
void startLoading() {
_onStartLoading?.call();
}
Puts the aquarium into loading mode, attracting all fish to circle around the center.
void startLoading() {
_onStartLoading?.call();
}