Aquatic enum
A unified species/type representing any fish or marine creature in the aquarium.
- Inheritance
- Available extensions
Values
- koiSanke → const Aquatic
- koiKohaku → const Aquatic
- koiTancho → const Aquatic
- goldfish → const Aquatic
- blackMoor → const Aquatic
- betta → const Aquatic
- blueTang → const Aquatic
- neonTetra → const Aquatic
- discus → const Aquatic
- angel → const Aquatic
- clownfish → const Aquatic
- guppy → const Aquatic
- jellyfish → const Aquatic
- turtle → const Aquatic
- manta → const Aquatic
- seahorse → const Aquatic
- starfish → const Aquatic
- crab → const Aquatic
Properties
- creatureType → CreatureType?
-
Available on Aquatic, provided by the AquaticMapper extension
Maps the unified species type to its internal CreatureType model.no setter - fishSpecies → FishSpecies?
-
Available on Aquatic, provided by the AquaticMapper extension
Maps the unified species type to its internal FishSpecies model.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isFish → bool
-
Available on Aquatic, provided by the AquaticMapper extension
Whether this species is a fish.no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited